#!/bin/bash

##################################################################################################################
#                                                                                                                #
#                  daccord Integration Package Exchange v.2.2.x - Installation script                            #
#                                                                                                                #
##################################################################################################################

# Set stage to either "DEVELOPMENT" or "PRODUCTION" to influence what repository the rpm files are pulled from
STAGE="PRODUCTION"
# Timestamp variable used to timestamp log entries
NOW=$(date +"%d-%m-%Y %T")
# Date variable used to give the logfile a name including the current date + hour & minute of creation
DATE=$(date +"%Y-%m-%d-%H-%M-%S")
# Logfile variable that holds the name of the logifle including the $DATE variable from above
LOGFILE=daccord-ip-exchange-install-${DATE}.log

# If the user id isn't 0, the script isn't being run as root and gives out a warning that it needs to be run as root to run successfully
CHECK_ROOTPRIVILEGE(){
    if [[ $EUID -ne 0 ]]; then
        echo -e "\033[0;31mThis script must be run with root privileges! Please verify that you have the needed privileges and restart the installation!\033[m"
        EXIT
    fi
}

# Check if the script is running on openSUSE or SLES or Red Hat
CHECK_OS(){
    cat /etc/os-release >> /dev/null 2>&1
    if [[ $? == 0 ]]; then
        OS=$(cat /etc/os-release | grep -e "^NAME=")
        if [[ ${OS} == 'NAME="openSUSE Leap"' ]] || [[ ${OS} == 'NAME="SLES"' ]]; then
            REDHAT="FALSE"
        else
            REDHAT="TRUE"
        fi
    else
        REDHAT="TRUE"
    fi
}

# Check if the stage variable is set to "DEVELOPMENT" and warn about it if set as such
CHECK_DEV(){
    if [[ $STAGE == "DEVELOPMENT" ]]; then
        echo -e "\033[0;31m\nWARNING! - This script is running in DEVELOPMENT mode.\033[m"
        echo -e "\033[0;31mIt will install or update from DEVELOPMENT repositories.\033[m"
    fi
}

# Check if the system currently has the daccord Integration Package Exchange already installed
CHECK_INST(){
    DACCORD_EX_STAT=-1
    if [[ -e /opt/GuH/daccord-exchange-gadget ]]; then
        DACCORD_EX_STAT=1
    fi
}

# Check if the system currently has the daccord Microsoft Edition already installed
CHECK_DAC_INST(){
    DACCORD_INST_SG_STAT=-1
    DACCORD_INST_CE_STAT=-1
    DACCORD_INST_PE_STAT=-1
    if [[ -e /opt/GuH/RuntimeEngine/webapps/system ]]; then
        DACCORD_INST_SG_STAT=1
    fi
    if [[ -e /opt/GuH/RuntimeEngine/webapps/collectorengine ]]; then
        DACCORD_INST_CE_STAT=1
    fi
    if [[ -e /opt/GuH/RuntimeEngine/webapps/policyengine ]]; then
        DACCORD_INST_PE_STAT=1
    fi
}

# Creates a file to let the script notice on the next run if the previous run finished prematurely
SET_PREVINSTALL_FLAG(){
    mkdir -p /opt/GuH/
    touch /opt/GuH/daccord_ex_install_flag
}

# Check if the file that is being created by the above funtion exists on this system
CHECK_PREVINSTALL_FLAG(){
    if [[ -e /opt/GuH/daccord_ex_install_flag ]]; then
        PREVINSTALL=1
    fi
}

OUTPUT_WELCOME(){
    clear
    echo -e "\033[0;36m################################################################################\033[m"
    echo -e "\033[0;36m#                                                                              #\033[m"
    echo -e "\033[0;36m#\033[m      \033[mdaccord Integration Package Exchange v.2.2.x - Installation script\033[m      \033[0;36m#\033[m"
    echo -e "\033[0;36m#                                                                              #\033[m"
    echo -e "\033[0;36m################################################################################\033[m"
    echo -e " "
    echo -e "For detailed information please refer to the logfile: ${PWD}/${LOGFILE}"
}

CANCEL(){
    echo "Canceling the install script!"
    echo "[${NOW} install.sh] Script has been canceled." >> ./${LOGFILE}
    exit 1
}

EXIT(){
    exit 1
}

PRESS_ANY_KEY(){
    echo -e "Press any key to continue."
    read -sn 1
}

ONLINE_INSTALL(){
    echo "[${NOW} install.sh] User has requested to start the online installation." >> ./${LOGFILE}
    echo -e "\n"
    EINGABE=
    while [[ ${EINGABE} != [iI] ]]; do
        read -p $'\033[0;36mPlease enter [i] to install the daccord Integration Package Exchange software now. [i] \033[m' EINGABE
        if [[ ${EINGABE} != [iI] ]]; then
            echo -e "\n\033[0;35mPlease enter [i] to install the daccord Integration Package Exchange software now. [i] \033[m"
        fi
    done
    if [[ ${EINGABE} == [iI] ]]; then
        echo -e "\nPlease wait while the daccord Integration Package Exchange software is being installed."
        INSTERROR=0
        if [[ ${REDHAT} == "TRUE" ]]; then
            ONLINE_REPO_INSTALL_REDHAT
        else
            ONLINE_REPO_INSTALL_SUSE
        fi
        if [[ $INSTERROR == "0" ]]; then
            echo -e "\nThe daccord Integration Package Exchange software components have been installed successfully!"
            echo -e "\n"
            rm -f /opt/GuH/daccord_ex_install_flag > /dev/null
        else
            echo -e "\n"
            echo -e "\033[1;31mSomething went wrong! An error was detected during the installation of the daccord Integration Package Exchange software components!\033[m"
            echo -e "\033[1;31mTo troubleshoot the installation please view the ${LOGFILE} file in the directory where the script file is located.\033[m"
            echo -e "\n"
        fi
    else
        CANCEL
    fi
}

ONLINE_REPO_INSTALL_SUSE(){
    echo "[${NOW} install.sh] Installing the daccord Integration Package Exchange components from the repository." >> ./${LOGFILE}
    if [[ ${STAGE} == "DEVELOPMENT" ]]; then
        zypper lr daccord-ip-exchange-2.2-dev >> /dev/null 2>&1
        if [[ $? == 0 ]]; then
            zypper mr -e daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
            echo -n '.'
        else
            zypper ar http://mirror.guh-systems.de/products/GuH/repos/update/daccord-ip-exchange-2.2-dev daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
            echo -n '.'
            zypper --gpg-auto-import-keys refresh daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
            echo -n '.'
        fi
    else
        zypper lr daccord-ip-exchange-2.2 >> /dev/null 2>&1
        if [[ $? == 0 ]]; then
            zypper mr -e daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
            echo -n '.'
        else
            zypper ar http://mirror.guh-systems.de/products/GuH/repos/update/daccord-ip-exchange-2.2 daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
            echo -n '.'
            zypper --gpg-auto-import-keys refresh daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
            echo -n '.'
        fi
    fi
    echo -n '.'
    systemctl stop RuntimeEngine.service >> ./${LOGFILE} 2>&1
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    sleep 10
    zypper --non-interactive in daccord-exchange-gadget >> ./${LOGFILE} 2>&1
    if [[ $? == 0 ]]; then
        echo -n '.'
        echo "[${NOW} install.sh] daccord-exchange-gadget installed successfully." >> ./${LOGFILE}
    else
        INSTERROR=1
        echo -n "Error while installing the daccord-exchange-gadget"
        echo "[${NOW} install.sh] Error while installing the daccord-exchange-gadget." >> ./${LOGFILE}
    fi
    systemctl start RuntimeEngine.service
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    if [[ ${STAGE} == "DEVELOPMENT" ]]; then
        zypper mr -d daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
    else
        zypper mr -d daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
    fi
}

ONLINE_REPO_INSTALL_REDHAT(){
    echo "[${NOW} install.sh] Installing the daccord Integration Package Exchange components from the repository." >> ./${LOGFILE}
    if [[ ${STAGE} == "DEVELOPMENT" ]]; then
        if [[ -f "/etc/yum.repos.d/daccord-ip-exchange-2.2-dev.repo" ]]; then
            yum config-manager --enable daccord-ip-exchange-2.2-dev.repo >> ./${LOGFILE} 2>&1
            echo -n '.'
        else
cat <<EOF>  /etc/yum.repos.d/daccord-ip-exchange-2.2-dev.repo
[daccord-ip-exchange-2.2-dev]
name=daccord ip exchange dev RPM Repository
baseurl=http://mirror.guh-systems.de/products/GuH/repos/update/daccord-ip-exchange-2.2-dev
enabled=1
gpgcheck=0
EOF
            echo -n '.'
        fi
    else
        if [[ -f "/etc/yum.repos.d/daccord-ip-exchange-2.2.repo" ]]; then
            yum config-manager --enable daccord-ip-exchange-2.2.repo >> ./${LOGFILE} 2>&1
            echo -n '.'
        else
cat <<EOF>  /etc/yum.repos.d/daccord-ip-exchange-2.2.repo
[daccord-ip-exchange-2.2]
name=daccord ip exchange RPM Repository
baseurl=http://mirror.guh-systems.de/products/GuH/repos/update/daccord-ip-exchange-2.2
enabled=1
gpgcheck=0
EOF
            echo -n '.'
        fi
    fi
    echo -n '.'
    systemctl stop RuntimeEngine.service >> ./${LOGFILE} 2>&1
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    sleep 10
    yum install -y daccord-exchange-gadget >> ./${LOGFILE} 2>&1
    if [[ $? == 0 ]]; then
        echo -n '.'
        echo "[${NOW} install.sh] daccord-exchange-gadget installed successfully." >> ./${LOGFILE}
    else
        INSTERROR=1
        echo -n "Error while installing the daccord-exchange-gadget"
        echo "[${NOW} install.sh] Error while installing the daccord-exchange-gadget." >> ./${LOGFILE}
    fi
    systemctl start RuntimeEngine.service
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    if [[ ${STAGE} == "DEVELOPMENT" ]]; then
        yum config-manager --disable daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
    else
        yum config-manager --disable daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
    fi
}

LOCAL_INSTALL(){
    echo "[${NOW} install.sh] User has requested to start the local installation." >> ./${LOGFILE}
    echo -e "\n"
    EINGABE=
    while [[ ${EINGABE} != [iI] ]]; do
        read -p $'\033[0;36mPlease enter [i] to install the daccord Integration Package Exchange software now. [i] \033[m' EINGABE
        if [[ ${EINGABE} != [iI] ]]; then
            echo -e "\n\033[0;35mPlease enter [i] to install the daccord Integration Package Exchange software now. [i]\033[m"
        fi
    done
    if [[ ${EINGABE} == [iI] ]]; then
        echo -e "\nPlease wait while the daccord Integration Package Exchange software is being installed."
        INSTERROR=0
        LOCAL_RPM_INSTALL
        if [[ $INSTERROR == "0" ]]; then
            echo -e "[${NOW} install.sh] The daccord Integration Package Exchange software components have been installed successfully!" >> ./${LOGFILE}
            echo -e "\nThe daccord Integration Package Exchange software components have been installed successfully!"
            echo -e "\n"
            rm -f /opt/GuH/daccord_ex_install_flag
        else
            echo -e "[${NOW} install.sh] Something went wrong! An error was detected during the installation of the daccord Integration Package Exchange components!" >> ./${LOGFILE}
            echo -e "\033[1;31mSomething went wrong! An error was detected during the installation of the daccord Integration Package Exchange components!\033[m"
            echo -e "\033[0;35mTo troubleshoot the installation please view the ${LOGFILE} file in the directory where the script file is located.\033[m"
            echo -e "\n"
        fi
    else
        CANCEL
    fi
}

LOCAL_RPM_INSTALL(){
    echo "[${NOW} install.sh] Installing the daccord Integration Package Exchange components from local RPM files." >> ./${LOGFILE}
        echo -n '.'
    systemctl stop RuntimeEngine.service >> ./${LOGFILE} 2>&1
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    sleep 10
    rpm -Uvh daccord-exchange-gadget* >> ./${LOGFILE} 2>&1
    if [[ $? == 0 ]]; then
        echo -n '.'
        echo "[${NOW} install.sh] daccord-exchange-gadget installed successfully." >> ./${LOGFILE}
    else
        INSTERROR=1
        echo -n "Error while installing the daccord-exchange-gadget"
        echo "[${NOW} install.sh] Error while installing the daccord-exchange-gadget." >> ./${LOGFILE}
    fi
    systemctl start RuntimeEngine.service
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
}

ONLINE_UPDATE(){
    echo "[${NOW} install.sh] User has requested to start the online update." >> ./${LOGFILE}
    echo -e "\nPlease wait while the daccord Integration Package Exchange software is being updated."
    INSTERROR=0
    if [[ ${REDHAT} == "TRUE" ]]; then
        ONLINE_REPO_UPDATE_REDHAT
    else
        ONLINE_REPO_UPDATE_SUSE
    fi
    if [[ $INSTERROR == "0" ]]; then
        echo -e "\nThe daccord Integration Package Exchange software components have been updated successfully!"
        echo -e "\n"
    else
        echo -e "\n"
        echo -e "\033[1;31mSomething went wrong! An error was detected during the update of the daccord Integration Package Exchange software components!\033[m"
        echo -e "\033[1;31mTo troubleshoot the update please view the ${LOGFILE} file in the directory where the script file is located.\033[m"
        echo -e "\n"
    fi
}

ONLINE_REPO_UPDATE_SUSE(){
    echo "[${NOW} install.sh] User has requested to update the daccord Integration Package Exchange components." >> ./${LOGFILE}
    if [[ ${STAGE} == "DEVELOPMENT" ]]; then
        zypper lr daccord-ip-exchange-2.2-dev >> /dev/null 2>&1
        if [[ $? == 0 ]]; then
            zypper mr -e daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
            zypper refresh daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
        else
            zypper ar http://mirror.guh-systems.de/products/GuH/repos/update/daccord-ip-exchange-2.2-dev daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
            zypper --gpg-auto-import-keys refresh daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
        fi
    else
        zypper lr daccord-ip-exchange-2.2 >> /dev/null 2>&1
        if [[ $? == 0 ]]; then
            zypper mr -e daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
            zypper refresh daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
        else
            zypper ar http://mirror.guh-systems.de/products/GuH/repos/update/daccord-ip-exchange-2.2 daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
            zypper --gpg-auto-import-keys refresh daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
        fi
    fi
    echo -n '.'
    systemctl stop RuntimeEngine.service >> ./${LOGFILE} 2>&1
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    sleep 10
    zypper --non-interactive up daccord-exchange-gadget >> ./${LOGFILE} 2>&1
    if [[ $? == 0 ]]; then
        echo -n '.'
        echo "[${NOW} install.sh] daccord-exchange-gadget installed successfully." >> ./${LOGFILE}
    else
        INSTERROR=1
        echo -n "Error while installing the daccord-exchange-gadget"
        echo "[${NOW} install.sh] Error while installing the daccord-exchange-gadget." >> ./${LOGFILE}
    fi
    systemctl start RuntimeEngine.service
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    if [[ ${STAGE} == "DEVELOPMENT" ]]; then
        zypper mr -d daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
    else
        zypper mr -d daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
    fi
    echo -e "\nThe daccord Integration Package Exchange components have been updated."
    echo "[${NOW} install.sh] The daccord Integration Package Exchange components have been updated." >> ./${LOGFILE}
    EXIT
}

ONLINE_REPO_UPDATE_REDHAT(){
    echo "[${NOW} install.sh] User has requested to update the daccord Integration Package Exchange components." >> ./${LOGFILE}
    if [[ ${STAGE} == "DEVELOPMENT" ]]; then
        if [[ ! -f "/etc/yum.repos.d/daccord-ip-exchange-2.2-dev.repo" ]]; then
cat <<EOF>  /etc/yum.repos.d/daccord-ip-exchange-2.2-dev.repo
[daccord-ip-exchange-2.2-dev]
name=daccord ip exchange dev RPM Repository
baseurl=http://mirror.guh-systems.de/products/GuH/repos/update/daccord-ip-exchange-2.2-dev
enabled=1
gpgcheck=0
EOF
        else
            yum config-manager --enable daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
        fi
    else
        if [[ ! -f "/etc/yum.repos.d/daccord-ip-exchange-2.2.repo" ]]; then
cat <<EOF>  /etc/yum.repos.d/daccord-ip-exchange-2.2.repo
[daccord-ip-exchange-2.2]
name=daccord ip exchange RPM Repository
baseurl=http://mirror.guh-systems.de/products/GuH/repos/update/daccord-ip-exchange-2.2
enabled=1
gpgcheck=0
EOF
        else
            yum config-manager --enable daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
        fi
    fi
    echo -n '.'
    yum clean all > /dev/null 2>&1
    echo -n '.'
    systemctl stop RuntimeEngine.service >> ./${LOGFILE} 2>&1
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    sleep 10
    yum upgrade -y daccord-exchange-gadget >> ./${LOGFILE} 2>&1
    if [[ $? == 0 ]]; then
        echo -n '.'
        echo "[${NOW} install.sh] daccord-exchange-gadget installed successfully." >> ./${LOGFILE}
    else
        INSTERROR=1
        echo -n "Error while installing the daccord-exchange-gadget"
        echo "[${NOW} install.sh] Error while installing the daccord-exchange-gadget." >> ./${LOGFILE}
    fi
    systemctl start RuntimeEngine.service
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    if [[ ${STAGE} == "DEVELOPMENT" ]]; then
        yum config-manager --disable daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
    else
        yum config-manager --disable daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
    fi
    echo -e "\nThe daccord Integration Package Exchange components have been updated."
    echo "[${NOW} install.sh] The daccord Integration Package Exchange components have been updated." >> ./${LOGFILE}
    EXIT
}

LOCAL_UPDATEL(){
    echo "[${NOW} install.sh] User has requested to start the local update." >> ./${LOGFILE}
    echo -e "\nPlease wait while the daccord Integration Package Exchange software is being updated."
    INSTERROR=0
    LOCAL_RPM_UPDATE
    if [[ $INSTERROR == "0" ]]; then
        echo -e "\nThe daccord Integration Package Exchange software components have been updated successfully!"
        echo -e "\n"
    else
        echo -e "\n"
        echo -e "\033[1;31mSomething went wrong! An error was detected during the update of the daccord Integration Package Exchange software components!\033[m"
        echo -e "\033[1;31mTo troubleshoot the update please view the ${LOGFILE} file in the directory where the script file is located.\033[m"
        echo -e "\n"
    fi
}

LOCAL_RPM_UDPATE(){
    echo "[${NOW} install.sh] User has requested to update the daccord Integration Package Exchange components." >> ./${LOGFILE}
        echo -n '.'
    systemctl stop RuntimeEngine.service >> ./${LOGFILE} 2>&1
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    sleep 10
    rpm -Uvh daccord-exchange-gadget* >> ./${LOGFILE} 2>&1
    if [[ $? == 0 ]]; then
        echo -n '.'
        echo "[${NOW} install.sh] daccord-exchange-gadget installed successfully." >> ./${LOGFILE}
    else
        INSTERROR=1
        echo -n "Error while installing the daccord-exchange-gadget"
        echo "[${NOW} install.sh] Error while installing the daccord-exchange-gadget." >> ./${LOGFILE}
    fi
    systemctl start RuntimeEngine.service
    if [[ $? != 0 ]]; then
        INSTERROR=1
    fi
    echo -e "\nThe daccord Integration Package Exchange components have been updated."
    echo "[${NOW} install.sh] The daccord Integration Package Exchange components have been updated." >> ./${LOGFILE}
    EXIT
}

UNINSTALL_SUSE(){
    echo "[${NOW} install.sh] User has requested to remove the daccord Integration Package Exchange components." >> ./${LOGFILE}
    echo -e "\nPlease wait while the daccord Integration Package Exchange components are being removed."
    zypper lr daccord-ip-exchange-2.2-dev >> /dev/null 2>&1
    if [[ $? == 0 ]]; then
        zypper rr daccord-ip-exchange-2.2-dev >> ./${LOGFILE} 2>&1
        echo -n '.'
    fi
    zypper lr daccord-ip-exchange-2.2 >> /dev/null 2>&1
    if [[ $? == 0 ]]; then
        zypper rr daccord-ip-exchange-2.2 >> ./${LOGFILE} 2>&1
        echo -n '.'
    fi
    systemctl stop RuntimeEngine.service >> ./${LOGFILE} 2>&1
    sleep 10
    echo -n '.'
    rpm -ve daccord-exchange-gadget >> ./${LOGFILE} 2>&1
    echo -n '.'
    rm -Rf /opt/GuH/RuntimeEngine/webapps/exchange >> ./${LOGFILE} 2>&1
    echo -n '.'
    rm -Rf /opt/GuH/RuntimeEngine/webapps/exchange.war >> /dev/null 2>&1
    echo -n '.'
    rm -Rf /opt/GuH/daccord-exchange-gadget >> /dev/null 2>&1
    echo -n '.'
    rm -Rf /var/opt/GuH/daccord-exchange-gadget >> /dev/null 2>&1
    echo -n '.'
    rm -Rf /opt/GuH/daccord-system-gagdet/res/integrationpackages/integrationpackage_5.xml
    echo -n '.'
    cypher-shell --username daccord --password daccord --database dbdaccord 'MATCH (ip:Integrationpackage {integrationpackageid: '5'})<-[:BELONGS_TO]-(n) OPTIONAL MATCH (n)-[:HAS]->(p) DETACH DELETE ip,p,n;' >> ./${LOGFILE} 2>&1
    echo -n '.'
    systemctl start RuntimeEngine.service
    echo -e "\nThe daccord Integration Package Exchange components have been removed."
    echo "[${NOW} install.sh] The daccord Integration Package Exchange components have been removed." >> ./${LOGFILE}
}

UNINSTALL_REDHAT(){
    echo "[${NOW} install.sh] User has requested to remove the daccord Integration Package Exchange components." >> ./${LOGFILE}
    echo -e "\nPlease wait while the daccord Integration Package Exchange components are being removed."
    if [[ ! -f "/etc/yum.repos.d/daccord-ip-exchange-2.2-dev.repo" ]]; then
        rm -f /etc/yum.repos.d/daccord-ip-exchange-2.2-dev.repo >> ./${LOGFILE} 2>&1
        echo -n '.'
    fi
    if [[ ! -f "/etc/yum.repos.d/daccord-ip-exchange-2.2.repo" ]]; then
        rm -f /etc/yum.repos.d/daccord-ip-exchange-2.2.repo >> ./${LOGFILE} 2>&1
        echo -n '.'
    fi
    systemctl stop RuntimeEngine.service >> ./${LOGFILE} 2>&1
    sleep 10
    echo -n '.'
    rpm -ve daccord-exchange-gadget >> ./${LOGFILE} 2>&1
    echo -n '.'
    rm -Rf /opt/GuH/RuntimeEngine/webapps/exchange >> ./${LOGFILE} 2>&1
    echo -n '.'
    rm -Rf /opt/GuH/RuntimeEngine/webapps/exchange.war >> /dev/null 2>&1
    echo -n '.'
    rm -Rf /opt/GuH/daccord-exchange-gadget >> /dev/null 2>&1
    echo -n '.'
    rm -Rf /var/opt/GuH/daccord-exchange-gadget >> /dev/null 2>&1
    echo -n '.'
    rm -Rf /opt/GuH/daccord-system-gagdet/res/integrationpackages/integrationpackage_5.xml
    echo -n '.'
    cypher-shell --username daccord --password daccord --database dbdaccord 'MATCH (ip:Integrationpackage {integrationpackageid: '5'})<-[:BELONGS_TO]-(n) OPTIONAL MATCH (n)-[:HAS]->(p) DETACH DELETE ip,p,n;' >> ./${LOGFILE} 2>&1
    echo -n '.'
    systemctl start RuntimeEngine.service
    echo -e "\nThe daccord Integration Package Exchange components have been removed."
    echo "[${NOW} install.sh] The daccord Integration Package Exchange components have been removed." >> ./${LOGFILE}
}

echo "[${NOW} install.sh] Script started." >> ./${LOGFILE} 2>&1
CHECK_ROOTPRIVILEGE
CHECK_OS
OUTPUT_WELCOME
CHECK_DEV
CHECK_INST
CHECK_DAC_INST
CHECK_PREVINSTALL_FLAG
while true; do
    if [[ ${DACCORD_INST_CE_STAT} != 1 ]] || [[ ${DACCORD_INST_PE_STAT} != 1 ]] || [[ ${DACCORD_INST_SG_STAT} != 1 ]]; then
        echo -e "\nWARNING! No daccord software installation has been detected on this system. The daccord Integration Package Exchange requires an already installed daccord software to function."
        EXIT
    elif [[ ${PREVINSTALL} = 1 ]]; then
        EINGABE=
        while [[ ${EINGABE} != [rRcC] ]]; do
            echo -e "[${NOW} install.sh] A previous unfinished installation has been detected on this system." >> ./${LOGFILE}
            echo -e "\nA previous unfinished installation has been detected on this system."
            read -p $'\033[0;36mWould you like to [r] remove all previously installed components or [c] cancel this installation? [r/c] \033[m' EINGABE
            if [[ ${EINGABE} != [rRcC] ]]; then
                echo -e "\n\033[0;35mPlease choose between [r] to remove or [c] to cancel!\033[m"
            fi
        done
        if [[ ${EINGABE} == [rR] ]]; then
            if [[ ${REDHAT} == "TRUE" ]]; then
                UNINSTALL_REDHAT
                rm /opt/GuH/daccord_ex_install_flag >> /dev/null 2>&1
                EXIT
            else
                UNINSTALL_SUSE
                rm /opt/GuH/daccord_ex_install_flag >> /dev/null 2>&1
                EXIT
            fi
        else
            CANCEL
        fi
    elif [[ ${DACCORD_EX_STAT} = 1 ]]; then
        EINGABE=
        while [[ ${EINGABE} != [uUrRcC] ]]; do
            echo -e "\nThere is already at least one daccord Integration Package Exchange component installed on this system."
            read -p $'\033[0;36mWould you like to update [u] the components, remove [r] the components or cancel [c] to exit the script? [u/r/c] \033[m' EINGABE
            if [[ ${EINGABE} != [uUrRcC] ]]; then
                echo -e "\n\033[0;35mPlease choose between update [u] the components, remove [r] the components or cancel [c] to exit the script!\033[m"
            fi
        done
        if [[ ${EINGABE} == [uU] ]]; then
            EINGABE=
            while [[ ${EINGABE} != [OoLl] ]]; do
                echo -e "\nThe install script provides two update modes."
                echo -e "     [o] Online mode - The components will be downloaded from their respective repositories and updated."
                echo -e "     [l] Local mode - The components will be updated from local rpm files. These need to be present in the directory this script is executed from."
                read -p  $'\033[0;36mPlease enter the letter for the desired update mode and confirm with the return key: [o/l] \033[m' EINGABE
                if [[ ${EINGABE} != [OoLl] ]]; then
                    echo -e "\n\033[0;35mPlease choose between [o] for online mode or [l] for local mode!\033[m"
                fi
            done
            if [[ ${EINGABE} == [Oo] ]]; then
                ONLINE_UPDATE
            else
                LOCAL_UDPATE
            fi
        elif [[ ${EINGABE} == [rR] ]]; then
            if [[ ${REDHAT} == "TRUE" ]]; then
                UNINSTALL_REDHAT
                EXIT
            else
                UNINSTALL_SUSE
                EXIT
            fi
        else
            CANCEL
        fi
    else
        EINGABE=
        while [[ ${EINGABE} != [OoLl] ]]; do
            echo -e "\nThe install script provides two installation modes."
            echo -e "     [o] Online mode - The required repositories will be added and the components will be downloaded from their respective repository."
            echo -e "     [l] Local mode - The components will be installed from local rpm files. These need to be present in the directory this script is executed from."
            read -p  $'\033[0;36mPlease enter the letter for the desired installation mode and confirm with the return key: [o/l] \033[m' EINGABE
            if [[ ${EINGABE} != [OoLl] ]]; then
                echo -e "\n\033[0;35mPlease choose between [o] for online mode or [l] for local mode!\033[m"
            fi
        done
        if [[ ${EINGABE} == [Oo] ]]; then
            SET_PREVINSTALL_FLAG
            ONLINE_INSTALL
            PRESS_ANY_KEY
            exit 1
        else
            SET_PREVINSTALL_FLAG
            if ls ./*.rpm > /dev/null 2>&1; then
                LOCAL_INSTALL
                PRESS_ANY_KEY
                exit 1
            else
                echo -e "\nNo rpm files have been found. Please make sure you have all required rpm files in the same directory as the install script."
                echo -e "[${NOW} install.sh] No rpm files have been found. Please make sure you have all required rpm files in the same directory as the install script." >> ./${LOGFILE}
                CANCEL
            fi
        fi
    fi
done
